﻿using System;
using System.Collections.Generic;
using System.Data;
using Kreta.Core.Domain;
using Kreta.DataAccess.Interfaces;
using Kreta.DataAccessManual.ParameterClasses;
using Kreta.Enums;

namespace Kreta.DataAccessManual.Interfaces
{
    public interface IAlkalmazottDal
    {
        void Delete(int id);
        void FollowUpAlkalmazott(int intezmenyId, int aktTanevId, int kovetkezoTanevId, int alkalmazottId);
        void FollowUpAlkalmazottCim(int intezmenyId, int tanevId, int kovTanevId, int alkalmazottId);
        void FollowUpAlkalmazottEmail(int intezmenyId, int tanevId, int kovTanevId, int alkalmazottId);
        void FollowUpAlkalmazottPEP(int intezmenyId, int aktTanevId, int kovetkezoTanevId, int PEPId);
        void FollowUpAlkalmazottTelefon(int intezmenyId, int tanevId, int kovTanevId, int alkalmazottId);
        void FollowUpAlkalmazottTovabbiMunkaugyiAdatok(int intezmenyId, int aktTanevId, int kovetkezoTanevId, int tovabbiMunkaugyiAdatId);
        void FollowUpAlkalmazottVegzettseg(int intezmenyId, int aktTanevId, int kovetkezoTanevId, int vegzettsegId);
        void FollowUpAlkalmazottVegzettsegKK(int intezmenyId, int aktTanevId, int kovetkezoTanevId, int alkalmazottId);
        void FullUpdate(IAlkalmazott dto);
        IAlkalmazott Get();
        IAlkalmazott Get(int id);
        int? GetAdminID(int tanevId, int intezmenyId);
        DataSet GetAlkalmazottak(int tanevId, List<int> felhasznaloIds = null);
        DataSet GetIskolaor(int tanevId);
        DataSet GetAlkalmazottakForTavolletjelento(int? alkalmazottFilterId, int tanevId, int intezmenyId);
        DataSet GetAlkalmazottakLakcimmelExcelExport(int tanevId, AlkalmazottSearchPco pco, bool showId = false);
        DataSet GetAlkalmazottakMunkaugyiAdataiExcelExport(int tanevId, bool isKlebersbergOrNSZFH, int intezmenyId, string intezmenyAzonosito, AlkalmazottSearchPco pco, bool isSelectedTanev21_22OrLater = false);
        DataSet GetAlkalmazottakSzemelyiAdataiExcelExport(int tanevId, AlkalmazottSearchPco pco);
        DataSet GetAlkalmazottakSapAzonositoi(int? alkalmazottId, int tanevId, int intezmenyId);
        KirAlkalmazottAlapadatok GetAlkalmazottAlapadatok(int id, int tanevId, int intezmenyId);
        KirAlkalmazottMunkaugyiAdatok GetAlkalmazottElsodlegesMunkaugyiAdatok(int id, int tanevId);
        DataSet GetAlkalmazottEszkozei(int userId, int tanevId, int intezmenyId);
        string GetAlkalmazottNevById(int id, int tanevId, int intezmenyId);
        DataSet GetAlkalmazottNeveEsEmailCime(int tanevId, int? emailTipus, IList<int> vezetoOraszamOka, int? userId);
        DataSet GetAlkalmazottakNeveEsEmailCimeVzetoOraszamOkAlapjan(int tanevId, int emailTipus, int intezmenyId, List<int> vezetoOraszamOka);
        DataSet GetAlkalmazottWithBelepesselDataSet(int tanevId);
        int GetAlklamazottMunkakorTipusa(int id);
        int? GetAlkalmazottFeladatEllatasiHelyId(int alkalmazottId, int tanevId);
        int GetBetoltetlenAllashelyekSzama(int tanevId, int intezmenyId);
        List<KirCim> GetKirAlkalmazottCim(int intezmenyId, int tanevId, IEnumerable<int> felhasznaloId, CimTipusEnum cimTipusEnum);
        int GetSpecialisAlkalmazottakSzama(int tanevId, string nevEloTag);
        DataSet GetSpecialisAlkalmazottakNeve(int tanevId, string nevEloTag);
        DataSet GetPedagogusIKTAdatszolgaltatasForGrid(int intezmenyId, int tanevId);
        bool HasSZTSZKOD(int alkalmazottId, int tanevId);
        bool HasValidMunkaviszony(int alkalmazottId, int tanevId);
        void Insert(IAlkalmazott dto, bool kellFollowUp = true);
        bool IsAlkalmazott(int felhasznaloId, int tanevId);
        bool IsAlkalmazottPedagogus(int intezmenyId, int tanevId, int alkalmazottId);
        DataSet GetInfoForLoginAlkalmazott(int alkalmazottId, int tanevId);
        bool IsKozossegiSzolgalatKezelo(int alkalmazottId, int tanevId);
        bool IsPortasMunkakor(int alkalmazottId, int tanevId);
        bool IsLEPKezelo(int alkalmazottId, int tanevId);
        bool AlkalmazottHasMentorCsoport(int alkalmazottId, int tanevId, int mentorCsoportId);
        bool IsLetezoFelhasznalonev(string felhasznaloNev);
        DataSet SearchAlkalmazott(AlkalmazottSearchPco pco, int intezmenyId, int tanevId, string intezmenyAzonosito);
        DataSet GetAlkalmazottakAlapErtekekkel(int pTanevId, string pSzuletesiHely, DateTime pSzuletesiDatum, string pNevKulso, string pNevKulsoGyak, string pNevHittanOktat, string pNevBetoltetlen);
        List<KirAlkalmazott> SearchAlkalmazottForKir(FelhasznaloKirSearchPco felhasznaloKirSearchPco, int tanevId);
        DataSet TanevValtasAlkalmazottTorlesKereses(int kovTanevId);
        DataSet GetAlkalmazottData(int tanevId);
        DataSet GetEszkozIgenylesAlkalmazottakExportData(int tanevId, bool isKellTovabbiMunkaugyiAdatok);
        void Update(IAlkalmazott dto, bool needFollowUp = true);
        void FollowUpById(int id);
        void UpdateAlkalmazottSzabadsagKeret(IDictionary<int, int> alkalmazottKeretek);
        DataSet GetAlkalmazottIDTavolletAlkalmazott(IList<int> alkalmazottIds, IList<string> alkalmazottSztszAzonositok);
        string GetSZTSZKOD(int felhasznaloId, int tanevId);
        int GetAlkalmazottIdByGUID(string alkalmazottGuid, int tanevId, int intezmenyId);
        /// <summary>
        /// Visszaadja az alkalmazott vezetőióraszám-okát.
        /// </summary>
        string IsLeader(int alkalmazottId, int tanevId);
        /// <summary>
        /// Visszaadja, hogy az alkmazott HR-kezelő-e.
        /// </summary>
        bool IsHrKezelo(int alkalmazottId, int tanevId);
        DataSet GetAlkalmazottTovabbkepzesek(int alkalmazottId);

        int GetKovTanevIdByAktTanevId(int id);
        bool AnyKozpontilagSzinkorizaltAlkalmazottFromList(List<int> alkalmazottIdList, int tanevId);
        DataSet GetAllAlkalmazottByIntezmeny(int intezmenyId, int tanevId);
        int? GetSzervezetId(int tanevId, int alkalmazottId);
    }
}
