﻿using System;
using System.Collections.Generic;
using System.Data;
using Kreta.Core.Domain;
using Kreta.DataAccess.Interfaces;
using Kreta.DataAccessManual.ParameterClasses;

namespace Kreta.DataAccessManual.Interfaces
{
    public interface IFelhasznaloDal
    {
        DataSet Check4TFelhOktAzonValidation(List<int> tanevIds, int pCheckValidationType,
            string pSzuletesiNevSorrend, string pSzuletesiNevElotag, string pSzuletesiCsaladiNev, string pSzuletesiUtonev,
            string pAnyjaNevSorrend, string pAnyjaElotag, string pAnyjaCsaladiNev, string pAnyjaUtonev, string pSzuletesiHely, DateTime? pSzuletesiDatum,
            string pOktatasiAzonosito, string pBejelentkezesiNev, int? pFelvetelStatuszaFelveve = null, int? pFelvetelStatuszaNemFelveve = null);
        void OktAzon4TAlapjanFollowUp(int validationType, int entityId, int anotherTanevEntityId);
        int? GetAktualisFelhasznaloBelepesID(string bejelentkezesiNev);
        string GetBejelentkezesiNev(Guid idpUniqueId);
        int? GetKovFelhasznaloBelepesID(string bejelentkezesiNev);
        string GetAktualisFelhasznaloBelepesJelszo(string bejelentkezesiNev);
        DataSet GetDatabases();
        DataSet GetSajatAdatlapCim(int userId, bool isGondviselo);
        DataSet GetUserCim(int userId);
        int GetUserDefaultLCID(int userId);
        DataSet GetUserEmailCim(int userId);
        string GetUserProfile();
        string GetUserProfile(int userId);
        DataSet GetUserTelefon(int userId);
        void HozzaferesGeneralas(int intezmenyId, int aktivTanevID, int userId, string belepesiAdatokXML);
        void JelszoFrissites(int intezmenyId, int aktivTanevID, int userId, string belepesiAdatokXML, bool isTanulo, int modositoUserId);
        bool CheckFelhasznaloHasSzerepkor(int felhasznaloId, int szerepkorTipusId);
        void Update(IFelhasznalo dto, bool handler);
        void UpdateProfile(IFelhasznalo entity, string profileXml);
        void UpdateProfile(int felhasznaloId, string profileXml);
        int GetFelhasznaloIdByUserName(string bejelentkezesiNev, int intezmenyId, int tanevId);
        void Delete(int id);
        void FullUpdate(IFelhasznalo dto);
        void Update(IFelhasznalo dto);
        IFelhasznalo Get();
        IFelhasznalo Get(int id);
        void Insert(IFelhasznalo dto);
        string GetTanuloFelhasznaloBelepesiNeve(int userId, int intezmenyId, int tanevId);
        string GetGondviseloFelhasznaloBelepesiNeve(int userId, int intezmenyId, int tanevId);
        bool IsCsokkentettGondviselo(int gondviseloId, int intezmenyId, int tanevId);
        DateTime GetTanuloFelhasznaloSzuletesiDatum(int userId, int intezmenyId, int tanevId);
        DateTime GetTanuloSzuletesiDatumByGondviseloId(int userId, int intezmenyId, int tanevId);
        bool GetVegzosEvfolyamTanulojaByUserId(int userId);
        DataSet GetFelhasznalok(int intezmenyId, int tanevId, FelhasznaloKeresesPCO pco, bool isHRModulEngedelyezett, bool isLepEngedelyezett);
        DataSet GetFelhasznalokOnlyAlkalmazottSzerepkor(int tanevId);
        DataSet GetAdminFelhasznalok(string intezmenyAzonosito);
        DataSet GetTanuloAdatForGondviselo(int userId);
        DataSet GetAlkalmazottakByOktatasiAzonosito(string oktatasiAzonosito, int tanevId);
        DataSet GetTanulokByOktatasiAzonosito(string oktatasiAzonosito, int tanevId);
        string GetFelhasznaloOktatasiAzonosito(int id, int tanevId);
        void FollowUpFelhasznaloEmail(int intezmenyId, int tanevId, int kovTanevId, int felhasznaloId);
        void FollowUpCim(int intezmenyId, int tanevId, int kovTanevId, int alkalmazottId);
        void FollowUpTelefon(int intezmenyId, int tanevId, int kovTanevId, int alkalmazottId);
        KirFelhasznaloElerhetosegek GetFelhasznaloElerhetoseg(int felhasznaloId, int value, bool isTanulo);
        void UpdateAllEgyediAzonosito();
        string GetFelhasznaloEgyediAzonosito(int intezmenyId, int userId);
        string GetFelhasznaloOktatasiAzonosito(int userId);
        string GetGondviseloEgyediAzonosito(int userId);
        int? GetFelhasznaloByEgyediAzonositoAndTanev(string egyediAzonosito, int tanevId);
        int? GetFelhasznaloByOktatasiAzonositoAndTanev(string okatatasiAzonosito, int tanevId);
        string GetFunkcioTeruletSAPKod(int felhasznaloId, int tanevId);
        DataSet GetFelhasznaloEmailByGuid(string felhasznaloEgyediAzonosit, int intezmenyId, int tanevId);
        bool IsTanuloOrGondviselo(int userId, int intezmenyId, int tanevId);
        DataSet GetCovidFertozottekDataSet(int tanevId);
        DataSet GetCovidFertozottekByTanarDataSet(int tanevId, int tanarId);
        IEgyHaztartasbanElok GetEgyhaztartasbanElok();
        IEgyHaztartasbanElok GetEgyhaztartasbanElok(int id);
        void DeleteEgyhaztartasbanElok(int id);
        void InsertEgyhaztartasbanElok(IEgyHaztartasbanElok dto);
        void FullUpdateEgyhaztartasbanElok(IEgyHaztartasbanElok dto);
        DataSet GetSapAdattisztasagExcel();
        DataSet UpdateFelhasznalokCovidAdatok(int tanevId, string tajSzamokJson);
        DataSet GetNapiErtesitesOsszefoglalo(int? tanuloId, int? tanuloIdp);
        List<int> GetAllIntezmenyiAdmin(int tanevId);
        string GetBankszamlaVezetoBankNeve(string intezmenyAzonosito, string bankszamlaSzam);
        void SaveBankszamlaAdatok(bool isTanulo, int felhasznaloId, string bankszamlaSzam, int? bankszamlaTulajdonosTipusID, string bankszamlaTulajNeve, int modifierId);
    }
}
