﻿using System;
using System.Collections.Generic;
using System.Data;
using Kreta.Core.Domain;
using Kreta.DataAccess.Interfaces;
using Kreta.DataAccessManual.ParameterClasses;
using Kreta.Enums;

namespace Kreta.DataAccessManual.Interfaces
{
    public interface ITanuloDal
    {
        bool CheckOktatasiAzonosito(string oktatasiAzonosito, int tanevId, int? felhasznaloId = 0);
        bool CheckTanuloNevUniqueLEP(int tanevId, string nev);
        DataSet CloneTanulo(int tanuloId, int trgTanevId, int intezmenyId, int srcTanevId, int felhasznaloId);
        void Delete(int id);
        void Delete(ITanulo dto);
        void FollowUpTanulo(int intezmenyId, int tanevId, int kovTanevId, int tanuloId);
        void FollowUpTanuloCim(int intezmenyId, int tanevId, int kovTanevId, int tanuloId);
        void FollowUpTanuloEmail(int intezmenyId, int tanevId, int kovTanevId, int tanuloId);
        void FollowUpTanuloFelmentes(int intezmenyId, int tanevId, int kovTanevId, int felmentesId);
        void FollowUpTanuloSni(int intezmenyId, int tanevId, int kovTanevId, int tanuloSniId);
        void FollowUpTanuloTelefon(int intezmenyId, int tanevId, int kovTanevId, int tanuloId);
        void FullUpdate(ITanulo dto);
        ITanulo Get();
        ITanulo Get(int id);
        DataSet GetAllGondviseloDataSet(int tanevId);
        DataSet GetAllTanuloDataSet(int tanevId);
        DataSet GetBesorolasTobbesModTanuloValidationItems(List<int> tanuloCsoportIdList = null);
        DataSet GetCsoportbolMaTorlendoTanulok();
        DataSet GetCsoportTanuloi(int osztalyId, int tanevId, string osztalyLista = null);
        string GetDiakigazolvanyszamByTanulo(int tanuloId, int tanevId);
        List<int> GetElozoOranHianyzottTanulok(DateTime oraKezdetDatuma, int osztalyCsoportId);
        DataSet GetErtekeles(int tanuloId, int? feladatKategoriaId);
        DataSet GetFeljegyzesekHavi(int tanuloId, int tanevId, int osztalyId);
        DataSet GetGondviseloCimekByGondviselo(int gondviseloId);
        DataSet GetGondviseloCimekByTanulo(int tanuloId, int tanevId);
        DataSet GetGondviselok(int userId, int tanevId);
        DataSet GetGondviseloAlapertelmezettAdatok(int tanuloId, int tanevId);
        DataSet GetGondviselokAdataiByOktatasiAzonosito(string oktatasiAzonosito);
        DataSet GetGondviselokElerhetosegei(int tanevId, TanuloKeresesPCO pco, bool isShowId = false);
        DataSet GetGondviseloUtolsoBelepes(int userId);
        DataSet GetGondviseloWithBelepesselDataSet(int tanevId);
        DataSet GetHistoria(int userId, int? feladatKategoriaId = null);
        DataSet GetIgazolasok(int userId, int? feladatKategoriaId);
        DataSet GetJogviszonySzuneteltetes(int userId, int? kategoria);
        List<KirCim> GetKirTanuloCim(int intezmenyId, int tanevId, IEnumerable<int> felhasznaloId, CimTipusEnum cimTipusEnum);
        int GetKovTanevId(string oktatasiAzonosito, int tanevId);
        DataSet GetKozossegiSzolgalat(int userId);
        double GetKozossegiSzolgalatOsszesOraszam(int intezmenyId, int tanuloId);
        DataSet GetMulasztasok(int userId, int? feladatKategoriaId);
        DataSet GetNemBesoroltTanulok();
        DataSet GetOrarend(int userId);
        DataSet GetOsztalyCsoportMindenkoriTanuloi(int osztalyId, string osztalyLista = null);
        DataSet GetOsztalyCsoportMindenkoriTanuloiTanuloCsoportonkent(int osztalyCsoportId);
        DataSet GetOsztalyTanuloi(int osztalyId, DateTime? date = null);
        DataSet GetTanorakonNemJelenlevokExcelExport(MulasztasKeresesePCO pco);
        DataSet GetTantargyak(int userId);
        DataSet GetTantargyFelosztasokByTanuloId(int tanuloId, int tanevId, int? tanarId = null, int? osztalyCsoportId = null, int? tantargyId = null, double? oraszam = null, DateTime? datum = null, int? feladatellatasihelyId = null, int? feladatKategoriaId = null);
        KirTanuloAlapadatok GetTanuloAlapadatok(int tanuloId, int tanevId);
        DataSet GetTanuloCsoportId(int userId, int? osztalyCsoportId, DateTime? tanevElsoNapja);
        DataSet GetTanuloCsoportjai(int tanuloId, bool csakAktualis = true);
        DataSet GetTanuloDataSet(int tanevId);
        DataSet GetTanuloDataSetByOsztalyCsoportId(int osztalyCsoportId, int? feladatKategoriaId, string nev, string anyjaSzuletesiNev, string szuletesiHely, DateTime? szuletesiIdoTol, DateTime? szuletesiIdoIg, string oktatasiAzonosito, bool? tankotelezett, int? tanterv, int? feladatEllatasiHelyId, DateTime datum);
        DataSet GetTanuloElerhetosegekEmail(int tanuloId, int tanevId);
        DataSet GetTanuloElerhetosegekTel(int tanuloId, int tanevId);
        DataSet GetTanulokFelmentesei(IEnumerable<int> tanuloIds, int tanevId, bool isFromSzervezet = false, int? tantargyId = null, int? dualisKepzesTantargyId = null);
        DataSet GetTanuloGondviseloListData(int intezmenyId, int tanevId, int userId);
        DataSet GetTanuloiAlapadatokGrid(int tanuloId, int osztalyCsoportId, int intezmenyId, int tanevId);
        int GetTanuloIdByOktatasiAzonosito(string oktatasiAzonosito, int tanevId);
        DataSet GetTanuloiEgyebAdatokGrid(int tanuloId, int intezmenyId, int tanevId, int? osztalyId);
        DataSet GetTanuloiGondviseloAdatokGrid(int tanuloId, int intezmenyId, int tanevId);
        DataSet GetTanulokByDiakigazolvanyszam(string diakigazolvanyszam, int tanevId);
        DataSet GetTanulokByOsztalyfonokForDDL(int ofoId);
        DataSet GetTanulokEsOsztalyokCsoportokGrid(BesorolasSearchPCO pco, bool isCsoport = false);
        DataSet GetTanulokForBelepesiAzonositoGeneralas(int intezmenyId, int tanevId, List<int> tanuloIdList, bool torolt = false, bool csakAkiknekNincsAzonositojuk = true, bool toroltFelhasznaloBelepes = false);
        DataSet GetTanulokForDDL(bool torolt = false);
        DataSet GetTanulokForJelszoReset(int intezmenyId, int tanevId);
        DataSet GetTanulokGondviseloiDDL(int tanuloId);
        DataSet GetTanulokGondviseloIdvalForBelepesiAzonositoGeneralas(int intezmenyId, int tanevId, List<int> tanuloIdList, bool torolt = false, bool csakAkiknekNincsAzonositojuk = true);
        DataSet GetTanuloKirStatExport(int tanevId, TanuloKeresesPCO pco);
        DataSet GetTanulokJegyeiByErtekelesTipusExcelExport(int tanevId, int tipusId, TanuloErtekelesListPco tanuloErtekelesListPco);
        DataSet GetTanulokLakcimmel(int intezmenyId, int tanevId, TanuloKeresesPCO pco, bool isShowId = false);
        DataSet GetTanulokMulasztasaiExcelExport(MulasztasKeresesePCO pco);
        DataSet GetTanulokOktatasiAzonositoja(int intezmenyId, int tanevId, bool torolt = false);
        DataSet GetTanulokTantargyaiEsPedagogusaiExcelExport(int tanevId, TanuloKeresesPCO pco);
        DataSet GetTanulokTanugyiAdatai(int tanevId, TanuloKeresesPCO pco, DateTime datum);
        DataSet GetTanulokWithOutBelepesWithGondviselo(int intezmenyId, int tanevId, List<int> tanuloIdList, bool torolt = false);
        DataSet GetTanuloModalHeader(int tanuloId);
        List<int> GetTanuloMulasztasaiFelmentesRogziteshez(int tanuloId, int tantargyId, bool egeszEvre = false);
        List<int> GetTanuloOktatasiNevelesiFeladatIdList(int intezmenyId, int tanevId, int tanuloId, OktNevelesiKategoriaEnum? oktatasiNevelesiKategoria = null);
        DataSet GetTanuloOraAdatai(int? orarendiOraId, int? tanitasiOraId, DateTime datum);
        DataSet GetTanuloOraSzamonkeresAdatai(int? orarendiOraId, int? tanitasiOraId, DateTime date);
        DataSet GetTanuloOsztaly(int tanuloId, DateTime? datum = null, OktNevelesiKategoriaEnum? feladatKategoria = OktNevelesiKategoriaEnum.NevelesOktatas, bool csakAktualis = true, bool feladatKategoriaval = false);
        DataSet GetTanuloOsztalyCsoport(int tanuloId, int osztalyId, DateTime datum);
        DataSet GetTanuloOsztalyCsoport(string commandText, Dictionary<string, object> commandParameterList);
        DataSet GetTanuloWithBelepesselDataSet(int tanevId);
        DataSet GetUtkozoCsoportok(int tanuloId, DateTime belepesDatum, int tanuloCsoportId, int atsorolasCsoportId, OktNevelesiKategoriaEnum? kategoria);
        DataSet GetUtkozoOsztalyok(int tanuloId, DateTime belepesDatum, int tanuloCsoportId, int atsorolasOsztalyId, OktNevelesiKategoriaEnum? kategoria);
        bool HasErtekelesekForTanuloInTanuloCsoport(int tanuloId, int tanuloCsoportId);
        bool HasMulasztasokForTanuloInTanuloCsoport(int tanuloId, int tanuloCsoportId);
        bool HasOsztalyBasorolas(int tanuloId);
        void Insert(ITanulo dto);
        bool IsTanulo(int felhasznaloId);
        DataSet KIRTanulokImport(string tanuloiAdatokXml, int intezmenyId, int tanevId, int userId);
        List<KirTanulo> SearchTanuloForKir(FelhasznaloKirSearchPco tanuloKirSearchCo, int tanevId, int tanuloId);
        DataSet TanuloKereses(TanuloKeresesPCO pco);
        void Update(ITanulo dto);
        void UpdateTanuloCsoportBesorolasDatum(List<string> ids, int userId, DateTime aktTanevSzept1Datum);
        void UpdateTanulokNKTesSZKTSzakkepzesesAdatok(string tanulokIdString, SzakkepzesesAdatokPCO szakkepzesesAdatok, bool isSzakkepzesesUpdate, bool isNKTSzakkepzesesUpdate);
        bool VanMasOsztalya(int tanuloId, int osztalyId, OktNevelesiKategoriaEnum? kategoria);
        DataSet GetSzakkepzesiJuttatasokTanulok(SzakkepzesiJuttatasokTanuloPCO pco);
        DataSet GetSzakkepzesiJuttatasokTanulokDashboardAdatok(int tanevId);
        DataSet GetBankszamlaIgenylesData(int tanevId, int tanuloId);
        IEnumerable<int> ListGondviseloByTanuloIds(IEnumerable<int> tanuloIds);
        DataSet GetTanuloAdatok(Guid tanuloIdpUniqueId);
        bool IsAllOsztalyAltalanosIskolaFeladatellatasiHely(List<int> osztalyIdList);
        DataSet GetTanuloOsztalyEvfolyam(int tanevId, int tanuloId, List<int> evfolyamTipusEnumIdList, OktNevelesiKategoriaEnum? feladatKategoria = null, DateTime? datum = null);
        DataSet GetTanulokEmailNelkulJelszoResethez(int tanevId, List<int> tanuloIds = null);
        DataSet GetOsztalyTanuloiGondviselokDataSet(int felhasznaloId, int intezmenyId, int tanevId, int? osztalyId, int? ellatottKoznevelesiFeladatId, bool isSzuperOsztalyfonok, bool isEvfolyamfelelos);
        bool IsTanuloEvfolyamTipusaLetezik(int tanuloId, int intezmenyId, int tanevId, IEnumerable<int> evfolyamTipusIdList);
        DataSet GetTanulokDigitalisOktatasEgyenloHozzaferes(int tanevId, int intezmenyId, List<int> evfolyamtipusIds, bool? isGondviseloLetezik = null, bool? isGondviseloBelepesLetezik = null, bool? isGondviseloTorvenyesKepviselo = null, bool? isGondviseloEszkozIgenylesElfogadottASZF = null);
        DataSet GetTanuloSzirBeallitasokExport(int tanevId, int intezmenyId, List<int> tanuloIds);
        DataSet GetJogviszonyByTanulo(int tanuloId, int tanevId, int intezmenyId);
        DataSet GetJogviszonyByTanuloIds(List<int> tanuloIdList, int tanevId, int intezmenyId);
        DataSet GetTanuloJogviszonyAdatok(int tanevId, int intezmenyId);
        DataSet GetMentessegDataSet(int tantargyId, int? tanuloId, DateTime datum);
        DataSet GetOsztalyCsoportTanuloAdatokDataSet(int tanuloId);
        DataSet GetSzakkepzesiMunkaszerzodesek(int intezmenyId, int tanevId, int tanuloId);
    }
}
